@@ -5,7 +5,7 @@
 #' @param custom_var_names A vector of custom variable names used in presentation that match the order of the \code{form} object passed to \code{fergm}.  If not provided, defaults to names inherited by \code{fergm.fit}.
 #' @return This prints a ggplot2 traceplot for the effects of interest.
 #' @keywords FERGM interpret summary
-#' @references Box-Steffensmeier, Janet M., Dino P. Christenson, and Jason W. Morgan. 2017. ``Modeling Unobserved Heterogeneity in Social Networks with the Frailty Exponential Random Graph Model." \emph{Political Analysis}.
+#' @references Box-Steffensmeier, Janet M., Dino P. Christenson, and Jason W. Morgan. 2018. ``Modeling Unobserved Heterogeneity in Social Networks with the Frailty Exponential Random Graph Model." \emph{Political Analysis}. (26)1:3-19.
 #' @references Stan Development Team (2016). RStan: the R interface to Stan. R package version 2.14.1. \url{http://mc-stan.org/}.
 #' @examples
 #' # load example data
@@ -27,8 +27,7 @@ fergm_beta_traceplot <- function(fergm.fit = NULL, custom_var_names = NULL){
   trace <- rstan::traceplot(fergm.fit$stan.fit, pars = "beta")
 
   if(is.null(custom_var_names)){
-    custom_var_names <- fergm.fit$form
-    custom_var_names <- stringr::str_replace_all(string = unlist(strsplit(custom_var_names, "[+]")), pattern=" ", repl="")
+    custom_var_names <- colnames(fergm.fit$stan.dta$x)
   }
 
   var_names <- custom_var_names
